==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Surveys/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_YOURNAME","Votre Nom");

define("_OK","Ok !");
define("_COMMENT","commentaire");

define("_CONFIGURE","Pr&eacute;f&eacute;rences");
define("_LOGINCREATE","Connexion/Cr&eacute;er un compte");
define("_THRESHOLD","Disposition");
define("_NOCOMMENTS","Pas de commentaires");
define("_NESTED","Emboit&eacute;s");
define("_FLAT","A plat");
define("_THREAD","Par discussions");
define("_OLDEST","Le plus vieux en premier");
define("_NEWEST","Le plus r&eacute;cent en premier");
define("_HIGHEST","Le plus haut score en premier");
define("_COMMENTSWARNING","Les commentaires sont la propri&eacute;t&eacute; de leurs auteurs. Nous ne sommes pas responsables de leurs contenus !");
define("_SCORE","Score:");


define("_USERINFO","Profil Utilisateur");
define("_READREST","Lire le reste du commentaire...");
define("_REPLY","R&eacute;pondre &agrave; ce message");
define("_REPLYMAIN","Poster un commentaire");
define("_NOSUBJECT","Pas de Sujet");
define("_NOANONCOMMENTS","Les commentaires anonymes ne sont pas autoris&eacute;s, veuillez vous <a href=\"user.php\">enregistrer</a>");
define("_PARENT","Parent");
define("_ROOT","Racine");

define("_UCOMMENT","Commentaire");
define("_ALLOWEDHTML","HTML autoris&eacute;:");
define("_POSTANON","Publication anonyme");
define("_EXTRANS","Extrans (html tags en texte)");
define("_HTMLFORMATED","Format HTML");
define("_PLAINTEXT","Texte seulement");
define("_ONN","le...");
define("_SUBJECT","Sujet");
define("_SURVEYCOM","Poster un commentaire sur le sondage");
define("_SURVEYCOMPRE","Pr&eacute;visualisation du commentaire");
define("_NOTRIGHT","Quelque chose s'est mal d&eacute;roul&eacute; en passant une variable &agrave; cette fonction. Ceci est un message d'avertissement pour pr&eacute;venir d'un probable disfonctionnement.");
define("_DIRECTCOM","Commentaire direct...");
define("_SENDAMSG","Envoyer un message");

define("_PASTSURVEYS","Derniers Sondages");



define("_LVOTES","votes");
define("_TOTALVOTES","Total des votes:");
define("_VOTING","Isoloir");
define("_OTHERPOLLS","Autres Sondages");
define("_CURRENTSURVEY","Sondage en cours");
define("_CURRENTPOLLRESULTS","R&eacute;sultats du sondage en cours");
define("_PREVIEW","Prvisualisation");


define("_REFRESH","Rafra&icirc;chir");
define("_SURVEYS","Sondages");
define("_ATTACHEDTOARTICLE","- Attach  l' article:");
define("_SURVEYSATTACHED","Sondage attach  l'article");


?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Surveys/language/lang-french.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/


define("_YOURNAME","Votre Nom");

define("_OK","Ok !");
define("_COMMENT","commentaire");

define("_CONFIGURE","Pr&eacute;f&eacute;rences");
define("_LOGINCREATE","Connexion/Cr&eacute;er un compte");
define("_THRESHOLD","Disposition");
define("_NOCOMMENTS","Pas de commentaires");
define("_NESTED","Emboit&eacute;s");
define("_FLAT","A plat");
define("_THREAD","Par discussions");
define("_OLDEST","Le plus vieux en premier");
define("_NEWEST","Le plus r&eacute;cent en premier");
define("_HIGHEST","Le plus haut score en premier");
define("_COMMENTSWARNING","Les commentaires sont la propri&eacute;t&eacute; de leurs auteurs. Nous ne sommes pas responsables de leurs contenus !");
define("_SCORE","Score:");


define("_USERINFO","Profil Utilisateur");
define("_READREST","Lire le reste du commentaire...");
define("_REPLY","R&eacute;pondre &agrave; ce message");
define("_REPLYMAIN","Poster un commentaire");
define("_NOSUBJECT","Pas de Sujet");
define("_NOANONCOMMENTS","Les commentaires anonymes ne sont pas autoris&eacute;s, veuillez vous <a href=\"user.php\">enregistrer</a>");
define("_PARENT","Parent");
define("_ROOT","Racine");

define("_UCOMMENT","Commentaire");
define("_ALLOWEDHTML","HTML autoris&eacute;:");
define("_POSTANON","Publication anonyme");
define("_EXTRANS","Extrans (html tags en texte)");
define("_HTMLFORMATED","Format HTML");
define("_PLAINTEXT","Texte seulement");
define("_ONN","le...");
define("_SUBJECT","Sujet");
define("_SURVEYCOM","Poster un commentaire sur le sondage");
define("_SURVEYCOMPRE","Pr&eacute;visualisation du commentaire");
define("_NOTRIGHT","Quelque chose s'est mal d&eacute;roul&eacute; en passant une variable &agrave; cette fonction. Ceci est un message d'avertissement pour pr&eacute;venir d'un probable disfonctionnement.");
define("_DIRECTCOM","Commentaire direct...");
define("_SENDAMSG","Envoyer un message");

define("_PASTSURVEYS","Derniers Sondages");



define("_LVOTES","votes");
define("_TOTALVOTES","Total des votes:");
define("_VOTING","Isoloir");
define("_OTHERPOLLS","Autres Sondages");
define("_CURRENTSURVEY","Sondage en cours");
define("_CURRENTPOLLRESULTS","R&eacute;sultats du sondage en cours");
define("_PREVIEW","Prvisualisation");


define("_REFRESH","Rafra&icirc;chir");
define("_SURVEYS","Sondages");
define("_ATTACHEDTOARTICLE","- Attach  l' article:");
define("_SURVEYSATTACHED","Sondage attach  l'article");


?>
